@@ -7,6 +7,9 @@
 from . import utf8
 from . import tscii
 
+import txt2unicode
+import txt2ipa
+
 def printchar( letters ):
     for c in letters: 
         print(c, u"\\u%04x"%ord(c))
